<?php

namespace GivePerFormGateways\FormExtension\DonationForm\Actions;

use Give\DonationForms\Models\DonationForm;
use Give\Framework\Blocks\BlockModel;

/**
 * This is an action that runs inside 'givewp_donation_form_enabled_gateways' to filter
 * which gateways should be enabled base on the Per Form Gateways settings.
 *
 * @since 2.0.0
 */
class InterceptDonationFormEnabledGateways
{
    /**
     * @since 2.0.0
     */
    public function __invoke($gateways, int $formId)
    {
        /**
         * 1. Get the donation form
         * 2. Get the givewp/payment-gateways block
         * 3. Check the block attributes for Per Form Gateways settings
         * 4. If block attributes are set, filter the global gateways and return only the ones present in the per-form gateways settings
         * 5. Otherwise, return the default global gateway settings
         */
        /** @var DonationForm $donationForm */
        $donationForm = DonationForm::find($formId);

        /** @var BlockModel $donationAmountBlock */
        $paymentGatewaysBlock = $donationForm->blocks->findByName("givewp/payment-gateways");

        if ( ! $paymentGatewaysBlock) {
            return $gateways;
        }

        $perFormGateways = $paymentGatewaysBlock->hasAttribute('perFormGateways') ? (array)$paymentGatewaysBlock->getAttribute('perFormGateways') : [];
        $useDefaultGateways = ! $paymentGatewaysBlock->hasAttribute(
                'useDefaultGateways'
            ) || (bool)$paymentGatewaysBlock->getAttribute('useDefaultGateways');

        if ( ! $useDefaultGateways && ! empty($perFormGateways)) {
            $perFormGatewayIds = array_column($perFormGateways, 'id');

            return array_intersect_key($gateways, array_flip($perFormGatewayIds));
        }

        return $gateways;
    }
}
