<?php

namespace GivePerFormGateways\FormExtension\FormBuilder\Actions;

use GivePerFormGateways\FormExtension\FormBuilder\ViewModels\PerFormGatewaysViewModel;

/**
 * @since 2.0.0
 */
class LoadFormExtensionAssets
{
    /**
     * @since 2.0.0
     */
    public function __invoke()
    {
        if (file_exists($this->getGlobalStylePath())) {
            wp_enqueue_style(
                'givewp-form-extension-per-form-gateways-global-style',
                $this->getGlobalStylePath()
            );
        }

        if (file_exists($this->getStylePath())) {
            wp_enqueue_style(
                'givewp-form-extension-per-form-gateways-style',
                $this->getStylePath()
            );
        }

        wp_enqueue_script(
            'givewp-form-extension-per-form-gateways',
            $this->getScriptPath(),
            $this->getScriptDependencies(),
            false,
            true
        );

        wp_localize_script('givewp-form-extension-per-form-gateways', 'perFormGatewaysFormBuilder',
            give(PerFormGatewaysViewModel::class)->exports());
    }

    /**
     * @since 2.0.0
     *
     * @see   https://developer.wordpress.org/block-editor/reference-guides/packages/packages-dependency-extraction-webpack-plugin/#wordpress
     */
    public function getScriptDependencies(): array
    {
        $path = GIVE_PER_FORM_GATEWAYS_URL . 'build/perFormGatewaysFormBuilderExtension.asset.php';

        $scriptAsset = file_exists($path) ? require $path : ['dependencies' => [], 'version' => filemtime($path)];

        return $scriptAsset['dependencies'];
    }

    /**
     * @since 2.0.0
     */
    public function getGlobalStylePath(): string
    {
        return GIVE_PER_FORM_GATEWAYS_URL . 'build/perFormGatewaysFormBuilderExtensionGlobalStyle.css';
    }

    /**
     * @since 2.0.0
     */
    public function getStylePath(): string
    {
        return GIVE_PER_FORM_GATEWAYS_URL . 'build/perFormGatewaysFormBuilderExtension.css';
    }

    /**
     * @since 2.0.0
     */
    public function getScriptPath(): string
    {
        return GIVE_PER_FORM_GATEWAYS_URL . 'build/perFormGatewaysFormBuilderExtension.js';
    }
}
