import { IGivePerFormGatewaysFormBuilder } from "./Interfaces/IGivePerFormGatewaysFormBuilder";
import { IGiveCore } from "./Interfaces/IGiveCore";
import { createHigherOrderComponent } from "@wordpress/compose";
import Settings from "./settings";

declare const window: {
    givewp: IGiveCore;
    perFormGatewaysFormBuilder: IGivePerFormGatewaysFormBuilder;
} & Window;

/**
 * @since 2.0.0
 */
export function getPerFormGatewaysFormBuilderWindowData() {
    return window.perFormGatewaysFormBuilder;
}

/**
 * This adds Per Form Gateways attributes to the GiveWP Donation Payment Gateways block.
 *
 * @since 2.0.0
 */
function addPerFormGatewaysSettings(settings, name) {
    if (name !== "givewp/payment-gateways") {
        return settings;
    }

    settings.attributes = {
        ...settings.attributes,
        useDefaultGateways: {
            type: "boolean",
            default: true,
        },
        perFormGateways: {
            type: "array",
            default: [],
        },
    };

    return settings;
}

/**
 * @see https://developer.wordpress.org/block-editor/reference-guides/filters/block-filters/#blocks-registerblocktype
 *
 * @since 2.0.0
 */
wp.hooks.addFilter(
    "blocks.registerBlockType",
    "givewp/payment-gateways",
    addPerFormGatewaysSettings
);

/**
 * This adds Per Form Gateways attribute settings to the GiveWP Payment Gateways block.
 *
 * @since 2.0.0
 */
const addPerFormGatewaysControls = createHigherOrderComponent((BlockEdit) => {
    return (props) => {
        return props.name !== "givewp/payment-gateways" ? (
            <BlockEdit {...props} />
        ) : (
            <>
                <Settings {...props} />
                <BlockEdit {...props} />
            </>
        );
    };
}, "withInspectorControl");

/**
 * @see https://developer.wordpress.org/block-editor/reference-guides/filters/block-filters/#editor-blockedit
 *
 * @since 2.0.0
 */
wp.hooks.addFilter(
    "editor.BlockEdit",
    "givewp/payment-gateways",
    addPerFormGatewaysControls
);
