import { InspectorControls } from "@wordpress/block-editor";
import { PanelBody, ToggleControl } from "@wordpress/components";
import type { BlockEditProps } from "@wordpress/blocks";
import { __ } from "@wordpress/i18n";
import { settings } from "../types/settings";
import { gatewayOption } from "../types/gatewayOption";
import { getPerFormGatewaysFormBuilderWindowData } from "../index";
import { useEffect } from "react";
import { OptionsPanel } from "@givewp/form-builder-library";
import { gateway } from "../types/gateway";

/**
 * @since 2.0.0
 */
export default function Settings({
    attributes,
    setAttributes,
}: BlockEditProps<any>) {
    const getEnabledGateways = (gatewayOptions: gatewayOption[]) =>
        gatewayOptions.filter((gateway: gatewayOption) => gateway.checked);

    const { gatewayOptions } = getPerFormGatewaysFormBuilderWindowData();
    const {
        useDefaultGateways = true,
        perFormGateways = getEnabledGateways(gatewayOptions),
    } = attributes as settings;

    useEffect(() => {
        for (let i = 0; i < gatewayOptions.length; i++) {
            const checked = perFormGateways.some(
                (gatewayOption: gatewayOption) =>
                    gatewayOption.id === gatewayOptions[i].id
            );

            gatewayOptions[i].checked = checked;

            wp.hooks.addFilter(
                `givewp_form_builder_payment_gateway_enabled_${gatewayOptions[i].id}`,
                "givewp/give-per-form-gateways",
                (enabled: boolean, gateway: gateway) => {
                    enabled = useDefaultGateways ? true : checked;

                    return enabled;
                }
            );
        }
    }, [perFormGateways, useDefaultGateways]);

    return (
        <InspectorControls>
            <PanelBody
                title={__("Form gateway options", "give-per-form-gateways")}
                initialOpen={true}
            >
                <ToggleControl
                    label={__("Use default gateways", "give-per-form-gateways")}
                    checked={useDefaultGateways}
                    onChange={() => {
                        setAttributes({
                            useDefaultGateways: !useDefaultGateways,
                        });
                    }}
                />

                {!useDefaultGateways && (
                    <>
                        <div>
                            {!!gatewayOptions && (
                                <OptionsPanel
                                    multiple={true}
                                    options={gatewayOptions}
                                    setOptions={(newOptions: any) =>
                                        setAttributes({
                                            perFormGateways:
                                                getEnabledGateways(newOptions),
                                        })
                                    }
                                    label={__(
                                        "ALLOWED GATEWAYS",
                                        "give-per-form-gateways"
                                    )}
                                    readOnly={true}
                                    disableSoloCheckedOption={true}
                                    draggable={false}
                                />
                            )}
                        </div>
                    </>
                )}
            </PanelBody>
        </InspectorControls>
    );
}
